@@ -6,8 +6,6 @@ This module contains a basic Word Model
 
 from __future__ import annotations
 
-from typing import List
-
 from flask_sqlalchemy import BaseQuery
 
 from loglan_db import db
@@ -16,12 +14,11 @@ from loglan_db.model_db import t_name_words, \
 from loglan_db.model_db.base_author import BaseAuthor
 from loglan_db.model_db.base_connect_tables import \
     t_connect_authors, t_connect_words, t_connect_keys
+from loglan_db.model_db.base_definition import BaseDefinition
 from loglan_db.model_db.base_event import BaseEvent
 from loglan_db.model_db.base_key import BaseKey
 from loglan_db.model_db.base_type import BaseType
 from loglan_db.model_init import InitBase, DBBase
-from loglan_db.model_db.base_definition import BaseDefinition
-from sqlalchemy.ext.hybrid import hybrid_property
 
 __pdoc__ = {
     'BaseWord.created': False, 'BaseWord.updated': False,
@@ -34,8 +31,6 @@ class BaseWord(db.Model, InitBase, DBBase):
 
     id = db.Column(db.Integer, primary_key=True)
     """Word's internal ID number: Integer"""
-
-    id_old = db.Column(db.Integer, nullable=False)  # Compatibility with the previous database
     name = db.Column(db.String(64), nullable=False)
     origin = db.Column(db.String(128))
     origin_x = db.Column(db.String(64))
@@ -43,34 +38,34 @@ class BaseWord(db.Model, InitBase, DBBase):
     rank = db.Column(db.String(8))
     year = db.Column(db.Date)
     notes = db.Column(db.JSON)
+
+    # Fields for legacy database compatibility
+    id_old = db.Column(db.Integer, nullable=False)
     TID_old = db.Column(db.Integer)  # references
 
+    # Relationships
     type_id = db.Column("type", db.ForeignKey(f'{t_name_types}.id'), nullable=False)
-    type: BaseType = db.relationship(
-        BaseType.__name__, back_populates="words")
+    _type: BaseType = db.relationship(
+        BaseType.__name__, back_populates="_words")
 
     event_start_id = db.Column(
         "event_start", db.ForeignKey(f'{t_name_events}.id'), nullable=False)
-    event_start: BaseEvent = db.relationship(
+    _event_start: BaseEvent = db.relationship(
         BaseEvent.__name__, foreign_keys=[event_start_id],
-        back_populates="appeared_words")
+        back_populates="_appeared_words")
 
     event_end_id = db.Column("event_end", db.ForeignKey(f'{t_name_events}.id'))
-    event_end: BaseEvent = db.relationship(
+    _event_end: BaseEvent = db.relationship(
         BaseEvent.__name__, foreign_keys=[event_end_id],
-        back_populates="deprecated_words")
+        back_populates="_deprecated_words")
 
-    authors: BaseQuery = db.relationship(
+    _authors: BaseQuery = db.relationship(
         BaseAuthor.__name__, secondary=t_connect_authors,
-        back_populates="contribution", lazy='dynamic')
+        back_populates="_contribution", lazy='dynamic', enable_typechecks=False)
 
     _definitions: BaseQuery = db.relationship(
         BaseDefinition.__name__, back_populates="_source_word", lazy='dynamic')
 
-    @hybrid_property
-    def definitions(self):
-        return self._definitions
-
     # word's derivatives
     _derivatives = db.relationship(
         'BaseWord', secondary=t_connect_words,
@@ -79,126 +74,100 @@ class BaseWord(db.Model, InitBase, DBBase):
         backref=db.backref('_parents', lazy='dynamic', enable_typechecks=False),
         lazy='dynamic', enable_typechecks=False)
 
-    @hybrid_property
-    def derivatives(self):
+    @property
+    def type(self) -> BaseQuery:
+        return self._type
+
+    @property
+    def event_start(self) -> BaseQuery:
+        return self._event_start
+
+    @property
+    def event_end(self) -> BaseQuery:
+        return self._event_end
+
+    @property
+    def authors(self) -> BaseQuery:
+        return self._authors
+
+    @property
+    def definitions(self) -> BaseQuery:
+        return self._definitions
+
+    @property
+    def derivatives(self) -> BaseQuery:
         return self._derivatives
 
-    def query_derivatives(self, word_type: str = None,
-                          word_type_x: str = None, word_group: str = None) -> BaseQuery:
+    def query_derivatives(
+            self, word_type: str = None, word_type_x: str = None,
+            word_group: str = None) -> BaseQuery:
         """Query to get all derivatives of the word, depending on its parameters
 
         Args:
           word_type: str:  (Default value = None)
+          E.g. "2-Cpx", "C-Prim", "LW"<hr>
+
           word_type_x: str:  (Default value = None)
+          E.g. "Predicate", "Name", "Affix"<hr>
+
           word_group: str:  (Default value = None)
+          E.g. "Cpx", "Prim", "Little"<hr>
 
         Returns:
             BaseQuery
         """
-        result = self.derivatives.filter(self.id == t_connect_words.c.parent_id)
 
-        if word_type or word_type_x or word_group:
-            result = result.join(BaseType)
+        type_values = [
+                (BaseType.type, word_type),
+                (BaseType.type_x, word_type_x),
+                (BaseType.group, word_group), ]
 
-        result = self.add_query_filters(result, word_type, word_type_x, word_group)
+        type_filters = [i[0] == i[1] for i in type_values if i[1]]
 
-        return result.order_by(type(self).name.asc())
+        return self._derivatives.join(BaseType)\
+            .filter(self.id == t_connect_words.c.parent_id, *type_filters)\
+            .order_by(type(self).name.asc())
+
+    @property
+    def parents(self) -> BaseQuery:
+        """Query to get all parents for Complexes, Little words or Affixes
 
-    @staticmethod
-    def add_query_filters(
-            result: BaseQuery, word_type: str = None,
-            word_type_x: str = None, word_group: str = None) -> BaseQuery:
-        """
-        Args:
-            result:
-            word_type:
-            word_type_x:
-            word_group:
         Returns:
+            BaseQuery
         """
-        if word_type:
-            result = result.filter(BaseType.type == word_type)
-        if word_type_x:
-            result = result.filter(BaseType.type_x == word_type_x)
-        if word_group:
-            result = result.filter(BaseType.group == word_group)
-        return result
+        return self._parents
 
-    def query_cpx(self) -> BaseQuery:
-        """Query to qet all the complexes that exist for this word
-        Only primitives have affixes
-
-        Args:
+    @property
+    def complexes(self) -> BaseQuery:
+        """
+        Get all word's complexes if exist
+        Only primitives and Little Words have complexes.
 
         Returns:
             BaseQuery
         """
         return self.query_derivatives(word_group="Cpx")
 
-    def query_afx(self) -> BaseQuery:
-        """Query to qet all the affixes that exist for this word
-        Only primitives have affixes
-
-        Args:
+    @property
+    def affixes(self) -> BaseQuery:
+        """
+        Get all word's affixes if exist
+        Only primitives have affixes.
 
         Returns:
             BaseQuery
         """
         return self.query_derivatives(word_type="Afx")
 
-    def query_keys(self) -> BaseQuery:
-        """Query for the BaseKeys linked with this BaseWord
+    @property
+    def keys(self) -> BaseQuery:
+        """Get all BaseKey object related to this BaseWord.
 
-        Args:
+        Keep in mind that duplicated keys from related definitions
+        will be counted with ```.count()``` but excluded from ```.all()``` request
 
         Returns:
             BaseQuery
         """
         return BaseKey.query.join(
             t_connect_keys, BaseDefinition, BaseWord).filter(BaseWord.id == self.id)
-
-    @property
-    def parents(self) -> List[BaseWord]:
-        """Get all parents of the Complexes, Little words or Affixes
-
-        Args:
-
-        Returns:
-            List[BaseWord]
-        """
-        return self._parents.all()
-
-    @property
-    def complexes(self) -> List[BaseWord]:
-        """Get all word's complexes if exist
-
-        Args:
-
-        Returns:
-            List[BaseWord]
-        """
-        return self.query_cpx().all()
-
-    @property
-    def affixes(self) -> List[BaseWord]:
-        """Get all word's affixes if exist
-
-        Args:
-
-        Returns:
-            List[BaseWord]
-        """
-        return self.query_afx().all()
-
-    @property
-    def keys(self) -> List[BaseKey]:
-        """Get all BaseKey object related to this BaseWord
-        Keep in mind that duplicate keys for different definitions
-        will not be added to the final result
-
-        Args:
-
-        Returns:
-            List[BaseKey]
-        """
-        return self.query_keys().all()
